@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -345,7 +345,7 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
 
     def __init__(self):
         """Initialize the 'walk' Search Method."""
-        CatfishSearchMethod.__init__(self, "walk")
+        super().__init__("walk")
         self.running = False
 
     def get_dir_list(self, root, dirs, xdg_list,
@@ -424,7 +424,8 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
             GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_DOWNLOAD),
             GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_MUSIC),
             GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_PICTURES),
-            GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_PUBLIC_SHARE),
+            GLib.get_user_special_dir(
+                GLib.UserDirectory.DIRECTORY_PUBLIC_SHARE),
             GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_TEMPLATES),
             GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_VIDEOS),
         ]
@@ -488,7 +489,7 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
 
     def __init__(self):
         """Initialize the 'fulltext' search method."""
-        CatfishSearchMethod.__init__(self, "fulltext")
+        super().__init__("fulltext")
         self.force_stop = False
         self.running = False
         self.exact = False
@@ -658,7 +659,7 @@ class CatfishSearchMethod_Zeitgeist(CatfishSearchMethod):
 
     def __init__(self):
         """Initialize the Zeitgeist SearchMethod."""
-        CatfishSearchMethod.__init__(self, "zeitgeist")
+        super().__init__("zeitgeist")
         self.stop_search = False
         self.events = []
 
@@ -726,7 +727,7 @@ class CatfishSearchMethodExternal(CatfishSearchMethod):
 
     def __init__(self, method_name):
         """Initialize the external method class."""
-        CatfishSearchMethod.__init__(self, method_name)
+        super().__init__(method_name)
         self.pid = -1
         self.command = []
         self.process = None
@@ -791,7 +792,7 @@ class CatfishSearchMethod_Locate(CatfishSearchMethodExternal):
 
     def __init__(self):
         """Initialize the Locate SearchMethod."""
-        CatfishSearchMethodExternal.__init__(self, "locate")
+        super().__init__("locate")
         self.caps = self.get_capabilities()
         if self.caps["existing"]:
             self.command = ["locate", "-i", "%path*%keywords*", "--existing"]
