@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -39,6 +39,16 @@ def check_gobject_version(major_version, minor_version, micro=0):
     return gobject_version >= (major_version, minor_version, micro)
 
 
+def xdg_current_desktop():
+    desktop = os.environ.get("ORIGINAL_XDG_CURRENT_DESKTOP", None)
+    if desktop is None:
+        desktop = os.environ.get("XDG_CURRENT_DESKTOP", "")
+    desktop = desktop.lower()
+    if desktop == "ubuntu:gnome":
+        return "gnome"
+    return desktop
+
+
 # Define a context manager to suppress stdout and stderr.
 class suppress_stdout_stderr(object):
     '''
